==> reference-0.1.2%2B1.tar.gz: android/src/main/java/github/penguin/reference/method_channel/MethodChannelReferencePairManager.java <==
package github.penguin.reference.method_channel;

import androidx.annotation.NonNull;
import github.penguin.reference.reference.LocalReference;
import github.penguin.reference.reference.PoolableReferencePairManager;
import github.penguin.reference.reference.RemoteReference;
import github.penguin.reference.reference.UnpairedReference;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodCodec;
import io.flutter.plugin.common.StandardMethodCodec;
import java.util.List;

public abstract class MethodChannelReferencePairManager extends PoolableReferencePairManager
    implements MethodChannel.MethodCallHandler {
  static final String METHOD_CREATE = "REFERENCE_CREATE";
  static final String METHOD_METHOD = "REFERENCE_METHOD";
  static final String METHOD_DISPOSE = "REFERENCE_DISPOSE";

  public final BinaryMessenger binaryMessenger;
  public final String channelName;
  public final MethodCodec methodCodec;
  public final MethodChannel channel;

  @SuppressWarnings("unused")
  public MethodChannelReferencePairManager(
      final List<Class<? extends LocalReference>> supportedClasses,
      final BinaryMessenger binaryMessenger,
      final String channelName) {
    this(supportedClasses, binaryMessenger, channelName, channelName, new ReferenceMessageCodec());
  }

  public MethodChannelReferencePairManager(
      final List<Class<? extends LocalReference>> supportedClasses,
      final BinaryMessenger binaryMessenger,
      final String channelName,
      final String poolId,
      final ReferenceMessageCodec messageCodec) {
    super(supportedClasses, poolId);
    this.binaryMessenger = binaryMessenger;
    this.channelName = channelName;
    methodCodec = new StandardMethodCodec(messageCodec);
    this.channel = new MethodChannel(binaryMessenger, channelName, methodCodec);
  }

  @Override
  public abstract MethodChannelRemoteHandler getRemoteHandler();

  @Override
  public void initialize() {
    super.initialize();
    channel.setMethodCallHandler(this);
  }

  @SuppressWarnings("unchecked")
  @Override
  public void onMethodCall(
      @NonNull MethodCall call, @NonNull final MethodChannel.Result channelResult) {
    try {
      switch (call.method) {
        case METHOD_CREATE:
          {
            final List<Object> arguments = (List<Object>) call.arguments;
            pairWithNewLocalReference(
                (RemoteReference) arguments.get(0),
                (Integer) arguments.get(1),
                (List<Object>) arguments.get(2));
            channelResult.success(null);
            break;
          }
        case METHOD_METHOD:
          {
            final List<Object> arguments = (List<Object>) call.arguments;
            final Object result;
            if (arguments.get(0) instanceof UnpairedReference) {
              result = invokeLocalMethodOnUnpairedReference((UnpairedReference) arguments.get(0),
                  (String) arguments.get(1),
                  (List<Object>) arguments.get(2));
            } else if (arguments.get(0) instanceof RemoteReference) {
              result =
                  invokeLocalMethod(
                      getPairedLocalReference((RemoteReference) arguments.get(0)),
                      (String) arguments.get(1),
                      (List<Object>) arguments.get(2));
            } else {
              // TODO: Explanation
              throw new IllegalArgumentException(arguments.toString());
            }
            channelResult.success(result);
            break;
          }
        case METHOD_DISPOSE:
          disposePairWithRemoteReference((RemoteReference) call.arguments);
          channelResult.success(null);
          break;
        default:
          channelResult.notImplemented();
      }
    } catch (Exception exception) {
      channelResult.error(
          exception.getClass().getName(),
          exception.getLocalizedMessage(),
          android.util.Log.getStackTraceString(exception));
    }
  }
}

==> reference-0.1.4%2B1.tar.gz: android/src/main/java/github/penguin/reference/method_channel/MethodChannelReferencePairManager.java <==
package github.penguin.reference.method_channel;

import androidx.annotation.NonNull;
import github.penguin.reference.reference.LocalReference;
import github.penguin.reference.reference.PoolableReferencePairManager;
import github.penguin.reference.reference.RemoteReference;
import github.penguin.reference.reference.UnpairedReference;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodCodec;
import io.flutter.plugin.common.StandardMethodCodec;
import java.util.List;

public abstract class MethodChannelReferencePairManager extends PoolableReferencePairManager
    implements MethodChannel.MethodCallHandler {
  static final String METHOD_CREATE = "REFERENCE_CREATE";
  static final String METHOD_STATIC_METHOD = "REFERENCE_STATIC_METHOD";
  static final String METHOD_METHOD = "REFERENCE_METHOD";
  static final String METHOD_DISPOSE = "REFERENCE_DISPOSE";

  public final BinaryMessenger binaryMessenger;
  public final String channelName;
  public final MethodCodec methodCodec;
  public final MethodChannel channel;

  @SuppressWarnings("unused")
  public MethodChannelReferencePairManager(
      final List<Class<? extends LocalReference>> supportedClasses,
      final BinaryMessenger binaryMessenger,
      final String channelName) {
    this(supportedClasses, binaryMessenger, channelName, channelName, new ReferenceMessageCodec());
  }

  public MethodChannelReferencePairManager(
      final List<Class<? extends LocalReference>> supportedClasses,
      final BinaryMessenger binaryMessenger,
      final String channelName,
      final String poolId,
      final ReferenceMessageCodec messageCodec) {
    super(supportedClasses, poolId);
    this.binaryMessenger = binaryMessenger;
    this.channelName = channelName;
    methodCodec = new StandardMethodCodec(messageCodec);
    this.channel = new MethodChannel(binaryMessenger, channelName, methodCodec);
  }

  @Override
  public abstract MethodChannelRemoteHandler getRemoteHandler();

  @Override
  public void initialize() {
    super.initialize();
    channel.setMethodCallHandler(this);
  }

  @SuppressWarnings("unchecked")
  @Override
  public void onMethodCall(
      @NonNull MethodCall call, @NonNull final MethodChannel.Result channelResult) {
    try {
      switch (call.method) {
        case METHOD_CREATE:
          {
            final List<Object> arguments = (List<Object>) call.arguments;
            pairWithNewLocalReference(
                (RemoteReference) arguments.get(0),
                (Integer) arguments.get(1),
                (List<Object>) arguments.get(2));
            channelResult.success(null);
            break;
          }
        case METHOD_STATIC_METHOD:
          {
            final List<Object> arguments = (List<Object>) call.arguments;
            final Object result =
                invokeLocalStaticMethod(
                    getReferenceClass((Integer) arguments.get(0)),
                    (String) arguments.get(1),
                    (List<Object>) arguments.get(2));
            channelResult.success(result);
            break;
          }
        case METHOD_METHOD:
          {
            final List<Object> arguments = (List<Object>) call.arguments;
            final Object result;
            if (arguments.get(0) instanceof UnpairedReference) {
              result =
                  invokeLocalMethodOnUnpairedReference(
                      (UnpairedReference) arguments.get(0),
                      (String) arguments.get(1),
                      (List<Object>) arguments.get(2));
            } else if (arguments.get(0) instanceof RemoteReference) {
              result =
                  invokeLocalMethod(
                      getPairedLocalReference((RemoteReference) arguments.get(0)),
                      (String) arguments.get(1),
                      (List<Object>) arguments.get(2));
            } else {
              // TODO: Explanation
              throw new IllegalArgumentException(arguments.toString());
            }
            channelResult.success(result);
            break;
          }
        case METHOD_DISPOSE:
          disposePairWithRemoteReference((RemoteReference) call.arguments);
          channelResult.success(null);
          break;
        default:
          channelResult.notImplemented();
      }
    } catch (Exception exception) {
      channelResult.error(
          exception.getClass().getName(),
          exception.getLocalizedMessage(),
          android.util.Log.getStackTraceString(exception));
    }
  }
}
